
# Pipe Strip

Install with `pipx install pipe-strip` (for an isolated environment) or `pip install pipe-strip`

Run with `pipe-strip`

![Pipe Strip](https://raw.githubusercontent.com/1j01/pipe-strip/v0.1.0/src/pipe_strip/resources/pipe_strip_v12.ans.svg)

The ANSI art automatically scales to fit your terminal size.

Cyclic mode (see `pipe-strip --help`) allows for infinite viewing of the Pipe Strip.

## License

<p xmlns:dct="http://purl.org/dc/terms/" xmlns:vcard="http://www.w3.org/2001/vcard-rdf/3.0#">
  <a rel="license"
     href="https://creativecommons.org/publicdomain/zero/1.0/">
    <img src="https://i.creativecommons.org/p/zero/1.0/88x31.png" style="border-style: none;" alt="CC0" />
  </a>
  <br />
  To the extent possible under law,
  <a rel="dct:publisher"
     href="https://isaiahodhner.io">
    <span property="dct:title">Isaiah Odhner</span></a>
  has waived all copyright and related or neighboring rights to
  <span property="dct:title">Pipe Strip</span>.
This work is published from:
<span property="vcard:Country" datatype="dct:ISO3166"
      content="US" about="https://isaiahodhner.io">
  United States</span>.
</p>
